[SCM] WebKit Debian packaging branch, debian/unstable, updated. debian/1.1.15-1-40151-g37bb677

mjs mjs at 268f45cc-cd09-0410-ab3c-d52691b4dbfc
Sat Sep 26 07:38:05 UTC 2009


The following commit has been merged in the debian/unstable branch:
commit 78f28e4ee58356e75ce6261bf8b8f418cfed6eeb
Author: mjs <mjs at 268f45cc-cd09-0410-ab3c-d52691b4dbfc>
Date:   Tue Apr 22 18:54:58 2003 +0000

    WebFoundation:
    
            Reviewed by Darin.
    
    	Adjusted for class renames.
    
            * AuthenticationManager.subproj/NSURLAuthenticationChallenge.h:
            * AuthenticationManager.subproj/NSURLAuthenticationChallenge.m:
            (-[NSURLAuthenticationChallengePrivate initWithProtectionSpace:defaultUsername:previousFailureCount:delegate:]):
            (-[NSURLAuthenticationChallengePrivate dealloc]):
            (-[NSURLAuthenticationChallenge _initWithProtectionSpace:defaultUsername:previousFailureCount:delegate:]):
            (-[NSURLAuthenticationChallenge _authenticationHandlerBusy]):
            (-[NSURLAuthenticationChallenge init]):
            (-[NSURLAuthenticationChallenge dealloc]):
            (-[NSURLAuthenticationChallenge protectionSpace]):
            (-[NSURLAuthenticationChallenge defaultUsername]):
            (-[NSURLAuthenticationChallenge previousFailureCount]):
            (-[NSURLAuthenticationChallenge useCredential:]):
            (-[NSURLAuthenticationChallenge cancel]):
            * AuthenticationManager.subproj/NSURLCredential.h:
            * AuthenticationManager.subproj/NSURLCredential.m:
            (-[NSURLCredential initWithUsername:password:remembered:]):
            (+[NSURLCredential credentialWithUsername:password:remembered:]):
            (-[NSURLCredential copyWithZone:]):
            * AuthenticationManager.subproj/NSURLCredentialStorage.h:
            * AuthenticationManager.subproj/NSURLCredentialStorage.m:
            (-[NSURLAuthenticationChallengeState initWithHandlersCopy:index:httpRequest:challenge:callback:context:]):
            (-[NSURLAuthenticationChallengeState dealloc]):
            (-[NSURLCredentialStoragePrivate init]):
            (-[NSURLCredentialStoragePrivate dealloc]):
            (-[NSURLCredentialStorage dealloc]):
            (-[NSURLCredentialStorage init]):
            (initSharedCredentialStorage):
            (initCredentialStorage):
            (_credentialStorage):
            (+[NSURLCredentialStorage sharedCredentialStorage]):
            (-[NSURLCredentialStorage addAuthenticationHandler:]):
            (-[NSURLCredentialStorage removeAuthenticationHandler:]):
            (-[NSURLCredentialStorage credentialsForProtectionSpace:]):
            (-[NSURLCredentialStorage addCredential:forProtectionSpace:]):
            (-[NSURLCredentialStorage removeCredential:forProtectionSpace:]):
            (-[NSURLCredentialStorage defaultCredentialForProtectionSpace:]):
            (-[NSURLCredentialStorage setDefaultCredential:forProtectionSpace:]):
            (-[NSURLCredentialStorage _internalInit]):
            (-[NSURLCredentialStorage _usernameForRealm:URL:]):
            (-[NSURLCredentialStorage _removePasswordForRealm:URL:]):
            (-[NSURLCredentialStorage _proxyUsernameForURL:]):
            (-[NSURLCredentialStorage _removeProxyPasswordForURL:]):
            (-[NSURLCredentialStorage _realmForURL:]):
            (-[NSURLCredentialStorage _setRealm:forURL:]):
            (-[NSURLCredentialStorage _proxyProtectionSpaceForURL:]):
            (-[NSURLCredentialStorage _setDefaultUserInfoFromURL:]):
            (-[NSURLCredentialStorage _invokeHandlersWithURL:realm:forRequest:failureCount:withCallback:context:]):
            (-[NSURLCredentialStorage _invokeHandlersWithURL:proxy:forRequest:failureCount:withCallback:context:]):
            (-[NSURLCredentialStorage _tryChallenge:]):
            (-[NSURLCredentialStorage _retryWaitingChallenges]):
            (-[NSURLCredentialStorage NSURLAuthenticationChallenge:useCredential:]):
            (-[NSURLCredentialStorage NSURLAuthenticationChallengeCancel:]):
            (-[NSURLCredentialStorage NSURLAuthenticationChallengeAuthenticationHandlerBusy:]):
            (-[NSURLCredentialStorage _applyHTTPProxyCredentials:]):
            (-[NSURLCredentialStorage _applyHTTPCredentials:]):
            (-[NSURLCredentialStorage _addCredentialsToInitialHTTPRequest:]):
            (-[NSURLCredentialStorage _checkForAuthenticationFailureInHTTPResponse:withURL:]):
            (-[NSURLCredentialStorage _addCredentialsToRetryHTTPRequest:afterFailureResponse:failureCount:withCallback:context:]):
            (-[NSURLCredentialStorage _cancelAddCredentialsToRetryHTTPRequest:]):
            (-[NSURLCredentialStorage _haveCredentialForURL:]):
            * AuthenticationManager.subproj/NSURLProtectionSpace.h:
            * AuthenticationManager.subproj/NSURLProtectionSpace.m:
            (-[NSURLProtectionSpace _internalInit]):
            (-[NSURLProtectionSpace copyWithZone:]):
            (-[NSURLProtectionSpace isEqual:]):
            * AuthenticationManager.subproj/WebAuthenticationHandler.h:
            * AuthenticationManager.subproj/WebAuthenticationHandlerDispatcher.h:
            * AuthenticationManager.subproj/WebAuthenticationHandlerDispatcher.m:
            (-[WebAuthenticationDispatchState dealloc]):
            (-[WebAuthenticationHandlerDispatcher _dispatchStartAuthentication:]):
            (-[WebAuthenticationHandlerDispatcher NSURLAuthenticationChallenge:useCredential:]):
            (-[WebAuthenticationHandlerDispatcher NSURLAuthenticationChallengeAuthenticationHandlerBusy:]):
            (-[WebAuthenticationHandlerDispatcher _dispatchCancelAuthentication:]):
            (-[WebAuthenticationHandlerDispatcher _dispatchAuthenticationDone:]):
            (-[WebAuthenticationHandlerDispatcher _dispatchAuthenticationHandlerBusy:]):
            (-[WebAuthenticationHandlerDispatcher initWithAuthenticationHandler:]):
            (-[WebAuthenticationHandlerDispatcher dealloc]):
            (-[WebAuthenticationHandlerDispatcher startAuthentication:]):
            (-[WebAuthenticationHandlerDispatcher cancelAuthentication:]):
            * AuthenticationManager.subproj/WebAuthenticationManagerCallback.h:
            * AuthenticationManager.subproj/WebAuthenticationManagerPrivate.h:
            * AuthenticationManager.subproj/WebAuthenticationRequestPrivate.h:
            * AuthenticationManager.subproj/WebCredentialStorage.h:
            * AuthenticationManager.subproj/WebCredentialStorage.m:
            (-[WebCredentialStorage _addCredential:forProtectionSpace:]):
            (-[WebCredentialStorage _rootSpaceForProtectionSpace:]):
            (-[WebCredentialStorage _protectionSpaceWithKeychainItem:isDefault:]):
            (-[WebCredentialStorage _secProtocolForProtectionSpace:]):
            (-[WebCredentialStorage _saveCredential:forProtectionSpace:isDefault:]):
            (-[WebCredentialStorage _updateDefaultState:forCredential:protectionSpace:]):
            (-[WebCredentialStorage _addKeychainItem:]):
            (-[WebCredentialStorage credentialsForProtectionSpace:]):
            (-[WebCredentialStorage addCredential:forProtectionSpace:]):
            (-[WebCredentialStorage removeCredential:forProtectionSpace:]):
            (-[WebCredentialStorage defaultCredentialForProtectionSpace:]):
            (-[WebCredentialStorage setDefaultCredential:forProtectionSpace:]):
            * AuthenticationManager.subproj/WebKeychainCredential.h:
            * ProtocolHandlers.subproj/WebCFNetworkHTTPProtocol.m:
            (-[WebCFNetworkHTTPProtocol addAuthenticationFieldsToHeader]):
            (-[WebCFNetworkHTTPProtocol stopLoading]):
            (-[WebCFNetworkHTTPProtocol performHTTPHeaderRead:andCall:]):
            * ProtocolHandlers.subproj/WebHTTPProtocol.h:
            * ProtocolHandlers.subproj/WebSimpleHTTPProtocol.m:
            (+[WebSimpleHTTPProtocol canInitWithRequest:]):
            * WebFoundation.exp:
    
    WebKit:
    
            Reviewed by Darin.
    
    	Renamed classes to match API document.
    
            * Panels.subproj/WebAuthenticationPanel.h:
            * Panels.subproj/WebAuthenticationPanel.m:
            (-[WebAuthenticationPanel setUpForChallenge:]):
            (-[WebAuthenticationPanel runAsModalDialogWithChallenge:]):
            (-[WebAuthenticationPanel runAsSheetOnWindow:withChallenge:]):
            (-[WebAuthenticationPanel sheetDidEnd:returnCode:contextInfo:]):
            * Panels.subproj/WebPanelAuthenticationHandler.h:
            * Panels.subproj/WebPanelAuthenticationHandler.m:
            (-[WebPanelAuthenticationHandler init]):
            (-[WebPanelAuthenticationHandler dealloc]):
            (-[WebPanelAuthenticationHandler isReadyToStartAuthentication:]):
            (-[WebPanelAuthenticationHandler startAuthentication:]):
            (-[WebPanelAuthenticationHandler cancelAuthentication:]):
            (-[WebPanelAuthenticationHandler _authenticationDoneWithChallenge:result:]):
            * Panels.subproj/WebStandardPanels.m:
            (-[WebStandardPanels setUsesStandardAuthenticationPanel:]):
    
    WebBrowser:
    
            Reviewed by Darin.
    
    	Adjusted for class renames.
    
            * AppController.m:
            (-[AppController removeAllCredentials]):
            * BookmarksViewController.m:
            (+[BookmarksViewController autoTabColumnTitle]):
            * FormCompletionController.h:
            * FormCompletionController.m:
            (protectionSpaceFromFrame):
            (+[FormCompletionController _frame:willSubmitLoginForm:withValues:formInfo:submissionListener:]):
            (+[FormCompletionController _passwordSheetDismissed:returnCode:contextInfo:]):
            (+[FormCompletionController _credentialMatchesForString:frame:]):
            (stringFromMatch):
            (+[FormCompletionController _autoFillPasswordInFrame:formInfo:]):
            (+[FormCompletionController credentialIsNeverSaveMarker:]):
            (-[FormCompletionController reflectSelectedRow]):
            * Preferences.subproj/PasswordsEditor.h:
            * Preferences.subproj/PasswordsEditor.m:
            (-[PasswordsEditor protectionSpaceForCredential:]):
            (-[PasswordsEditor addressStringForCredential:]):
            (compareCredentials):
            (-[PasswordsEditor resetCredentials]):
            (-[PasswordsEditor startMonitoringCredentials]):
            (-[PasswordsEditor stopMonitoringCredentials]):
            (-[PasswordsEditor removeSelectedItems:]):
            (-[PasswordsEditor tableView:objectValueForTableColumn:row:]):
    
    
    git-svn-id: http://svn.webkit.org/repository/webkit/trunk@4153 268f45cc-cd09-0410-ab3c-d52691b4dbfc

diff --git a/WebKit/ChangeLog b/WebKit/ChangeLog
index 256b7b0..867518f 100644
--- a/WebKit/ChangeLog
+++ b/WebKit/ChangeLog
@@ -1,3 +1,26 @@
+2003-04-22  Maciej Stachowiak  <mjs at apple.com>
+
+        Reviewed by Darin.
+
+	Renamed classes to match API document.
+	
+        * Panels.subproj/WebAuthenticationPanel.h:
+        * Panels.subproj/WebAuthenticationPanel.m:
+        (-[WebAuthenticationPanel setUpForChallenge:]):
+        (-[WebAuthenticationPanel runAsModalDialogWithChallenge:]):
+        (-[WebAuthenticationPanel runAsSheetOnWindow:withChallenge:]):
+        (-[WebAuthenticationPanel sheetDidEnd:returnCode:contextInfo:]):
+        * Panels.subproj/WebPanelAuthenticationHandler.h:
+        * Panels.subproj/WebPanelAuthenticationHandler.m:
+        (-[WebPanelAuthenticationHandler init]):
+        (-[WebPanelAuthenticationHandler dealloc]):
+        (-[WebPanelAuthenticationHandler isReadyToStartAuthentication:]):
+        (-[WebPanelAuthenticationHandler startAuthentication:]):
+        (-[WebPanelAuthenticationHandler cancelAuthentication:]):
+        (-[WebPanelAuthenticationHandler _authenticationDoneWithChallenge:result:]):
+        * Panels.subproj/WebStandardPanels.m:
+        (-[WebStandardPanels setUsesStandardAuthenticationPanel:]):
+
 2003-04-21  Ken Kocienda  <kocienda at apple.com>
 
         Reviewed by Darin
diff --git a/WebKit/Panels.subproj/WebAuthenticationPanel.h b/WebKit/Panels.subproj/WebAuthenticationPanel.h
index 9b8f918..b530d6a 100644
--- a/WebKit/Panels.subproj/WebAuthenticationPanel.h
+++ b/WebKit/Panels.subproj/WebAuthenticationPanel.h
@@ -20,7 +20,7 @@
     BOOL usingSheet;
     id callback;
     SEL selector;
-    WebAuthenticationRequest *request;
+    NSURLAuthenticationChallenge *challenge;
 }
 
 -(id)initWithCallback:(id)cb selector:(SEL)sel;
@@ -31,8 +31,8 @@
 
 - (BOOL)loadNib;
 
-- (void)runAsModalDialogWithRequest:(WebAuthenticationRequest *)req;
-- (void)runAsSheetOnWindow:(NSWindow *)window withRequest:(WebAuthenticationRequest *)req;
+- (void)runAsModalDialogWithChallenge:(NSURLAuthenticationChallenge *)chall;
+- (void)runAsSheetOnWindow:(NSWindow *)window withChallenge:(NSURLAuthenticationChallenge *)chall;
 
 - (void)sheetDidEnd:(NSWindow *)sheet returnCode:(int)returnCode contextInfo:(void  *)contextInfo;
 
diff --git a/WebKit/Panels.subproj/WebPanelAuthenticationHandler.h b/WebKit/Panels.subproj/WebPanelAuthenticationHandler.h
index 5932b4b..7954168 100644
--- a/WebKit/Panels.subproj/WebPanelAuthenticationHandler.h
+++ b/WebKit/Panels.subproj/WebPanelAuthenticationHandler.h
@@ -11,7 +11,7 @@
 @interface WebPanelAuthenticationHandler : NSObject <WebAuthenticationHandler>
 {
     NSMutableDictionary *windowToPanel;
-    NSMutableDictionary *requestToWindow;
+    NSMutableDictionary *challengeToWindow;
 }
 
 @end
diff --git a/WebKit/Panels.subproj/WebPanelAuthenticationHandler.m b/WebKit/Panels.subproj/WebPanelAuthenticationHandler.m
index ad89caf..202ff21 100644
--- a/WebKit/Panels.subproj/WebPanelAuthenticationHandler.m
+++ b/WebKit/Panels.subproj/WebPanelAuthenticationHandler.m
@@ -19,7 +19,7 @@ static NSString *WebModalDialogPretendWindow = @"WebModalDialogPretendWindow";
     self = [super init];
     if (self != nil) {
         windowToPanel = [[NSMutableDictionary alloc] init];
-        requestToWindow = [[NSMutableDictionary alloc] init];
+        challengeToWindow = [[NSMutableDictionary alloc] init];
     }
     return self;
 }
@@ -27,14 +27,14 @@ static NSString *WebModalDialogPretendWindow = @"WebModalDialogPretendWindow";
 -(void)dealloc
 {
     [windowToPanel release];
-    [requestToWindow release];    
+    [challengeToWindow release];    
     [super dealloc];
 }
 
 // WebAuthenticationHandler methods
--(BOOL)isReadyToStartAuthentication:(WebAuthenticationRequest *)request
+-(BOOL)isReadyToStartAuthentication:(NSURLAuthenticationChallenge *)challenge
 {
-    id window = [[WebStandardPanels sharedStandardPanels] frontmostWindowLoadingURL:[[request resource] URL]];
+    id window = [[WebStandardPanels sharedStandardPanels] frontmostWindowLoadingURL:[[challenge protectionSpace] URL]];
 
     if (window == nil) {
         window = WebModalDialogPretendWindow;
@@ -43,49 +43,49 @@ static NSString *WebModalDialogPretendWindow = @"WebModalDialogPretendWindow";
     return [windowToPanel objectForKey:window] == nil;
 }
 
--(void)startAuthentication:(WebAuthenticationRequest *)request
+-(void)startAuthentication:(NSURLAuthenticationChallenge *)challenge
 {
-    id window = [[WebStandardPanels sharedStandardPanels] frontmostWindowLoadingURL:[[request resource] URL]];
+    id window = [[WebStandardPanels sharedStandardPanels] frontmostWindowLoadingURL:[[challenge protectionSpace] URL]];
 
     if (window == nil) {
         window = WebModalDialogPretendWindow;
     }
 
     if ([windowToPanel objectForKey:window] != nil) {
-        [request cancel];
+        [challenge cancel];
         return;
     }
 
-    WebAuthenticationPanel *panel = [[WebAuthenticationPanel alloc] initWithCallback:self selector:@selector(_authenticationDoneWithRequest:result:)];
-    [requestToWindow _web_setObject:window forUncopiedKey:request];
+    WebAuthenticationPanel *panel = [[WebAuthenticationPanel alloc] initWithCallback:self selector:@selector(_authenticationDoneWithChallenge:result:)];
+    [challengeToWindow _web_setObject:window forUncopiedKey:challenge];
     [windowToPanel _web_setObject:panel forUncopiedKey:window];
     [panel release];
     
     if (window == WebModalDialogPretendWindow) {
-        [panel runAsModalDialogWithRequest:request];
+        [panel runAsModalDialogWithChallenge:challenge];
     } else {
-        [panel runAsSheetOnWindow:window withRequest:request];
+        [panel runAsSheetOnWindow:window withChallenge:challenge];
     }
 }
 
--(void)cancelAuthentication:(WebAuthenticationRequest *)request
+-(void)cancelAuthentication:(NSURLAuthenticationChallenge *)challenge
 {
-    id window = [requestToWindow objectForKey:request];
+    id window = [challengeToWindow objectForKey:challenge];
     if (window != nil) {
         WebAuthenticationPanel *panel = [windowToPanel objectForKey:window];
         [panel cancel:self];
     }
 }
 
--(void)_authenticationDoneWithRequest:(WebAuthenticationRequest *)request result:(WebCredential *)credential
+-(void)_authenticationDoneWithChallenge:(NSURLAuthenticationChallenge *)challenge result:(NSURLCredential *)credential
 {
-    id window = [requestToWindow objectForKey:request];
+    id window = [challengeToWindow objectForKey:challenge];
     if (window != nil) {
         [windowToPanel removeObjectForKey:window];
-        [requestToWindow removeObjectForKey:request];
+        [challengeToWindow removeObjectForKey:challenge];
     }
 
-    [request useCredential:credential];
+    [challenge useCredential:credential];
 }
 
 @end
diff --git a/WebKit/Panels.subproj/WebStandardPanels.m b/WebKit/Panels.subproj/WebStandardPanels.m
index bac32a9..e54857c 100644
--- a/WebKit/Panels.subproj/WebStandardPanels.m
+++ b/WebKit/Panels.subproj/WebStandardPanels.m
@@ -88,11 +88,11 @@ static void initSharedStandardPanels(void)
     if (use) {
         if (![self usesStandardAuthenticationPanel]) {
             _privatePanels->panelAuthenticationHandler = [[WebPanelAuthenticationHandler alloc] init];
-            [[WebAuthenticationManager sharedAuthenticationManager] addAuthenticationHandler:_privatePanels->panelAuthenticationHandler];
+            [[NSURLCredentialStorage sharedCredentialStorage] addAuthenticationHandler:_privatePanels->panelAuthenticationHandler];
         }
     } else {
         if ([self usesStandardAuthenticationPanel]) {
-            [[WebAuthenticationManager sharedAuthenticationManager] removeAuthenticationHandler:_privatePanels->panelAuthenticationHandler];
+            [[NSURLCredentialStorage sharedCredentialStorage] removeAuthenticationHandler:_privatePanels->panelAuthenticationHandler];
             [_privatePanels->panelAuthenticationHandler release];
             _privatePanels->panelAuthenticationHandler = nil;
         }        

diff --git a/WebKit/Panels.subproj/WebAuthenticationPanel.m b/WebKit/Panels.subproj/WebAuthenticationPanel.m
index 482f28c..896a63d 100644
--- a/WebKit/Panels.subproj/WebAuthenticationPanel.m
+++ b/WebKit/Panels.subproj/WebAuthenticationPanel.m
@@ -88,37 +88,37 @@
 
 // Methods related to displaying the panel
 
--(void)setUpForRequest:(WebAuthenticationRequest *)req
+-(void)setUpForChallenge:(NSURLAuthenticationChallenge *)chall
 {
     [self loadNib];
 
-    WebAuthenticatingResource *resource = [req resource];
+    NSURLProtectionSpace *space = [chall  protectionSpace];
 
     NSString *host;
-    if ([resource port] == 0) {
-	host = [resource host];
+    if ([space port] == 0) {
+	host = [space host];
     } else {
-	host = [NSString stringWithFormat:@"%@:%u", [resource host], [resource port]];
+	host = [NSString stringWithFormat:@"%@:%u", [space host], [space port]];
     }
 
-    NSString *realm = [resource realm];
+    NSString *realm = [space realm];
     NSString *message;
 
-    if ([req previousFailureCount] == 0) {
-        if ([resource isProxy]) {
+    if ([chall previousFailureCount] == 0) {
+        if ([space isProxy]) {
             message = [NSString stringWithFormat:UI_STRING("To view this page, you need to log in to the %@ proxy server %@.",
                                                            "prompt string in authentication panel"),
-                [resource type], host];
+                [space type], host];
         } else {
             message = [NSString stringWithFormat:UI_STRING("To view this page, you need to log in to area “%@” on %@.",
                                                            "prompt string in authentication panel"),
                 realm, host];
         }
     } else {
-        if ([resource isProxy]) {
+        if ([space isProxy]) {
             message = [NSString stringWithFormat:UI_STRING("The name or password entered for the %@ proxy server %@ was incorrect. Please try again.",
                                                            "prompt string in authentication panel"),
-				[resource type], host];
+				[space type], host];
         } else {
             message = [NSString stringWithFormat:UI_STRING("The name or password entered for area “%@” on %@ was incorrect. Please try again.",
                                                            "prompt string in authentication panel"),
@@ -129,7 +129,7 @@
     [mainLabel setStringValue:message];
     [mainLabel sizeToFitAndAdjustWindowHeight];
 
-    if ([resource receivesCredentialSecurely]) {
+    if ([space receivesCredentialSecurely]) {
         [smallLabel setStringValue:
             UI_STRING("Your log-in information will be sent securely.",
                 "message in authentication panel")];
@@ -139,8 +139,8 @@
                 "message in authentication panel")];
     }
 
-    if ([req defaultUsername] != nil) {
-        [username setStringValue:[req defaultUsername]];
+    if ([chall defaultUsername] != nil) {
+        [username setStringValue:[chall defaultUsername]];
         [panel setInitialFirstResponder:password];
     } else {
         [username setStringValue:@""];
@@ -149,49 +149,49 @@
     }
 }
 
-- (void)runAsModalDialogWithRequest:(WebAuthenticationRequest *)req
+- (void)runAsModalDialogWithChallenge:(NSURLAuthenticationChallenge *)chall
 {
-    [self setUpForRequest:req];
+    [self setUpForChallenge:chall];
     usingSheet = FALSE;
-    WebCredential *credential = nil;
+    NSURLCredential *credential = nil;
 
     if ([[NSApplication sharedApplication] runModalForWindow:panel] == 0) {
-        credential = [WebCredential credentialWithUsername:[username stringValue] password:[password stringValue] remembered:[remember state] == NSOnState];
+        credential = [NSURLCredential credentialWithUsername:[username stringValue] password:[password stringValue] remembered:[remember state] == NSOnState];
     }
 
-    [callback performSelector:selector withObject:req withObject:credential];
+    [callback performSelector:selector withObject:chall withObject:credential];
 }
 
-- (void)runAsSheetOnWindow:(NSWindow *)window withRequest:(WebAuthenticationRequest *)req
+- (void)runAsSheetOnWindow:(NSWindow *)window withChallenge:(NSURLAuthenticationChallenge *)chall
 {
     ASSERT(!usingSheet);
 
-    [self setUpForRequest:req];
+    [self setUpForChallenge:chall];
 
     usingSheet = TRUE;
-    request = [req retain];
+    chall = [chall retain];
     
     [[NSApplication sharedApplication] beginSheet:panel modalForWindow:window modalDelegate:self didEndSelector:@selector(sheetDidEnd:returnCode:contextInfo:) contextInfo:NULL];
 }
 
 - (void)sheetDidEnd:(NSWindow *)sheet returnCode:(int)returnCode contextInfo:(void  *)contextInfo
 {
-    WebCredential *credential = nil;
-    WebAuthenticationRequest *req;
+    NSURLCredential *credential = nil;
+    NSURLAuthenticationChallenge *chall;
 
     ASSERT(usingSheet);
-    ASSERT(request != nil);
+    ASSERT(challenge != nil);
 
     if (returnCode == 0) {
-        credential = [WebCredential credentialWithUsername:[username stringValue] password:[password stringValue] remembered:[remember state] == NSOnState];
+        credential = [NSURLCredential credentialWithUsername:[username stringValue] password:[password stringValue] remembered:[remember state] == NSOnState];
     }
 
     // We take this tricky approach to nilling out and releasing the request,
     // because the callback below might remove our last ref.
-    req = request;
-    request = nil;
-    [callback performSelector:selector withObject:req withObject:credential];
-    [req release];
+    chall = challenge;
+    challenge = nil;
+    [callback performSelector:selector withObject:chall withObject:credential];
+    [chall release];
 }
 
 @end
@@ -149,49 +149,49 @@
     }
 
-    // We take this tricky approach to nilling out and releasing the request,
+    // We take this tricky approach to nilling out and releasing the challenge
     // because the callback below might remove our last ref.
-- 
WebKit Debian packaging



More information about the Pkg-webkit-commits mailing list